module.exports = function setup(options, imports, register) {

    var express = require('express'),
        app = express(),
        http = require('http'),
        connect = require('connect'),
        util = require('util'),
        crypto = require('crypto'),
        fs = require('fs'),
        path = require('path');

    // listen on local interface for production, all for dev/testing
    var defaultHost = '127.0.0.1';
    if(process.env.NODE_ENV === 'development' || process.env.NODE_ENV === 'testing') {
        defaultHost = '0.0.0.0';
    }

    options.port = options.port ? options.port : 8890;
    options.host = options.host ? options.host : defaultHost;

    var server = http.createServer(app),
        io = require('socket.io').listen(server);

    // App Configuration
    app.configure(function() {
        app.use(express.bodyParser());
    });

    io.configure(function () {
        io.set('log level', 1);
        io.set('browser client cache', false);
        io.set('resource', '/usg');

        if(app.settings.env !== 'testing') {
             // test environment settings
        }
    });


    app.get('/status', function(req, res) {
        res.json(200, {success: true});
    });

    io.sockets.on('connection', function (socket) {
        socket.on('status', function (data) {
            socket.emit('status', {success: true});
        });
    });

    server.listen(options.port, options.host, function (err) {
        if (err) return register(err);
        console.log("Ubuntu Server API listening on http://%s%s/", options.host, ":" + options.port);
        register(null, {
            // When a plugin is unloaded, it's onDestruct function will be called if there is one.
            onDestruct: function (callback) {
                server.close(callback);
            },
            http: server,
            socket_io: io,
            express: app
        });
    });

};